==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/StackedSplineAreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalStackedSeriesBaseDescriptionMetadata } from "./HorizontalStackedSeriesBaseDescriptionMetadata";
import { StackedSplineAreaSeriesDescription } from "./StackedSplineAreaSeriesDescription";
/**
 * @hidden
 */
var StackedSplineAreaSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(StackedSplineAreaSeriesDescriptionMetadata, _super);
    function StackedSplineAreaSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    StackedSplineAreaSeriesDescriptionMetadata.b = function (a) {
        if (StackedSplineAreaSeriesDescriptionMetadata.a == null) {
            StackedSplineAreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            StackedSplineAreaSeriesDescriptionMetadata.c(StackedSplineAreaSeriesDescriptionMetadata.a);
        }
        if (a.j(StackedSplineAreaSeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(StackedSplineAreaSeriesDescriptionMetadata.a);
    };
    StackedSplineAreaSeriesDescriptionMetadata.c = function (a) {
        HorizontalStackedSeriesBaseDescriptionMetadata.c(a);
        a.item("IsSplineShapePartOfRange", "Boolean");
    };
    StackedSplineAreaSeriesDescriptionMetadata.d = function (a) {
        StackedSplineAreaSeriesDescriptionMetadata.b(a);
        a.aa("StackedSplineAreaSeries", function () { return new StackedSplineAreaSeriesDescription(); });
        a.z("StackedSplineAreaSeries", StackedSplineAreaSeriesDescriptionMetadata.a);
    };
    StackedSplineAreaSeriesDescriptionMetadata.$t = markType(StackedSplineAreaSeriesDescriptionMetadata, 'StackedSplineAreaSeriesDescriptionMetadata');
    StackedSplineAreaSeriesDescriptionMetadata.a = null;
    return StackedSplineAreaSeriesDescriptionMetadata;
}(Base));
export { StackedSplineAreaSeriesDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/StackedSplineAreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { HorizontalStackedSeriesBaseDescriptionMetadata } from "./HorizontalStackedSeriesBaseDescriptionMetadata";
import { StackedSplineAreaSeriesDescription } from "./StackedSplineAreaSeriesDescription";
/**
 * @hidden
 */
var StackedSplineAreaSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(StackedSplineAreaSeriesDescriptionMetadata, _super);
    function StackedSplineAreaSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    StackedSplineAreaSeriesDescriptionMetadata.b = function (a) {
        if (StackedSplineAreaSeriesDescriptionMetadata.a == null) {
            StackedSplineAreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            StackedSplineAreaSeriesDescriptionMetadata.c(StackedSplineAreaSeriesDescriptionMetadata.a);
        }
        if (a.k(StackedSplineAreaSeriesDescriptionMetadata.a)) {
            return;
        }
        a.aa(StackedSplineAreaSeriesDescriptionMetadata.a);
    };
    StackedSplineAreaSeriesDescriptionMetadata.c = function (a) {
        HorizontalStackedSeriesBaseDescriptionMetadata.c(a);
        a.item("IsSplineShapePartOfRange", "Boolean");
    };
    StackedSplineAreaSeriesDescriptionMetadata.d = function (a) {
        StackedSplineAreaSeriesDescriptionMetadata.b(a);
        a.ac("StackedSplineAreaSeries", function () { return new StackedSplineAreaSeriesDescription(); });
        a.ab("StackedSplineAreaSeries", StackedSplineAreaSeriesDescriptionMetadata.a);
    };
    StackedSplineAreaSeriesDescriptionMetadata.$t = markType(StackedSplineAreaSeriesDescriptionMetadata, 'StackedSplineAreaSeriesDescriptionMetadata');
    StackedSplineAreaSeriesDescriptionMetadata.a = null;
    return StackedSplineAreaSeriesDescriptionMetadata;
}(Base));
export { StackedSplineAreaSeriesDescriptionMetadata };
